
#include "ResolveNameToObject.h"

#include <iostream>
using std::cerr;
using std::endl;

using std::string;

CORBA::Object_ptr ResolveNameToObject(
   CORBA::ORB_ptr orb, 
   const string &contextName, 
   const string &objectName)
{
   CosNaming::NamingContext_var rootContext;
  
   try 
   {
      // Obtain a reference to the root context of the Name service:
      
      CORBA::Object_var obj = orb->resolve_initial_references("NameService");

      rootContext = CosNaming::NamingContext::_narrow(obj);

      if(CORBA::is_nil(rootContext)) 
      {
         cerr << "Failed to narrow the root naming context." << endl;
         return CORBA::Object::_nil();
      }
   }
   catch(CORBA::ORB::InvalidName& ) 
   {

      cerr << "Service required is invalid [does not exist]." << endl;
      return CORBA::Object::_nil();
  }


  // Create a name object, containing the name test/context:
  CosNaming::Name name;
  name.length(2);

  name[0].id   = contextName.c_str();
  name[0].kind = (const char*) "JetByte Context"; 
  name[1].id   = objectName.c_str();
  name[1].kind = (const char*) "Object";

  try 
  {
    return rootContext->resolve(name);
  }
  catch(CosNaming::NamingContext::NotFound &) 
  {
    cerr << "CosNaming::NamingContext::NotFound" << endl;
    cerr << "Context not found" << endl;
  }
  catch(CORBA::COMM_FAILURE &) 
  {
    cerr << "System exception: COMM_FAILURE" << endl;
  }
  catch(CORBA::SystemException &) 
  {
    cerr << "System exception:" << endl;
  }

  return CORBA::Object::_nil();
}
